==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/ComboChangeEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { ComboChangeType_$type } from "./ComboChangeType";
/**
 * @hidden
 */
var ComboChangeEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ComboChangeEventArgsDetail, _super);
    function ComboChangeEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(ComboChangeEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.e.m("newValue");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("newValue", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ComboChangeEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.e.m("items");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("items", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ComboChangeEventArgsDetail.prototype, "c", {
        get: function () {
            var ret_ = this.e.m("type");
            ret_ = enumGetBox(ComboChangeType_$type, EnumUtil.getEnumValue(ComboChangeType_$type, this.e.f(ComboChangeType_$type, ret_)));
            return EnumUtil.getEnumValue(ComboChangeType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ComboChangeType_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.e.u("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ComboChangeEventArgsDetail.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ComboChangeEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.d.n = this.f;
        },
        enumerable: false,
        configurable: true
    });
    ComboChangeEventArgsDetail.$t = markType(ComboChangeEventArgsDetail, 'ComboChangeEventArgsDetail');
    return ComboChangeEventArgsDetail;
}(Base));
export { ComboChangeEventArgsDetail };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/ComboChangeEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { ComboChangeType_$type } from "./ComboChangeType";
/**
 * @hidden
 */
var ComboChangeEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ComboChangeEventArgsDetail, _super);
    function ComboChangeEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(ComboChangeEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.e.n("newValue");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("newValue", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ComboChangeEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.e.n("items");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("items", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ComboChangeEventArgsDetail.prototype, "c", {
        get: function () {
            var ret_ = this.e.n("type");
            ret_ = enumGetBox(ComboChangeType_$type, EnumUtil.getEnumValue(ComboChangeType_$type, this.e.f(ComboChangeType_$type, ret_)));
            return EnumUtil.getEnumValue(ComboChangeType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ComboChangeType_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ComboChangeEventArgsDetail.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ComboChangeEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.d.o = this.f;
        },
        enumerable: false,
        configurable: true
    });
    ComboChangeEventArgsDetail.$t = markType(ComboChangeEventArgsDetail, 'ComboChangeEventArgsDetail');
    return ComboChangeEventArgsDetail;
}(Base));
export { ComboChangeEventArgsDetail };
